using System;
using System.Xml;

using Grid;
using Grid.ContextSpace;
using Grid.Commands;

using UVa.GCG.WSRF.Common.WS.Addressing;

namespace ExtensionLibrary
{
	public class Extension1Entry : AbstractGridEntry
	{
		public Extension1Entry(
			EndpointReferenceType epr,
			string entryName,
			XmlQualifiedName entryType,
			IEntry parent)
			: base(epr, entryName, entryType, parent)
		{
		}

		public override LsFormat format(bool isLong)
		{
			return new LsFormat(EntryName, "[EXT1]");
		}
	}

	public class Extension1EntryFactory : AbstractEntryFactory
	{
		public Extension1EntryFactory()
			: base("Extension1", new XmlQualifiedName(
				"Extension1", "http://www.mark-morgan.net"))
		{
		}

		public override IEntry create(string name, EndpointReferenceType epr, IEntry parent)
		{
			return new Extension1Entry(epr, name, EntryType, parent);	
		}
	}

	public class EchoCommand : ICommand
	{
		private string []_parms;

		public EchoCommand(string []parms)
		{
			_parms = parms;
		}

		#region ICommand Members

		public void run()
		{
			foreach (string parm in _parms)
			{
				Grid.Env.GridLibEnvironment.Instance.Console.Output.WriteLine(
					"{0}", parm);
			}
		}

		#endregion
	}

	public class EchoCommandFactory : ICommandFactory
	{
		#region ICommandFactory Members

		public ICommand create(ICommandLineParser commandLine)
		{
			return new EchoCommand(commandLine.Arguments);
		}

		public string CommandName
		{
			get
			{
				return "echo";
			}
		}

		public string Usage
		{
			get
			{
				return "echo [param1] [param2] ...";
			}
		}

		#endregion
	}
}