// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Web;
using System.Web.Services;
using System.Web.Services.Protocols;
using System.Xml;
using System.Xml.Serialization;

using UVa.GCG.WSRF.Common.Attributes;
using UVa.GCG.WSRF.Common.WS.Addressing;
using UVa.GCG.WSRF.Common.WS.ServiceGroup;
using UVa.GCG.WSRF.Service.BaseTypes;
using UVa.GCG.WSRF.Service.ResourceLifetime;
using UVa.GCG.WSRF.Service.ResourceProperties;
using UVa.GCG.WSRF.Service.ServiceGroup;

using Grid;
using Grid.ContextSpace;

namespace BasicContexts
{
	/// <summary>
	/// This class is mostly empty because it is serving as a place holder
	/// for creating a web service using the WSRF.NET PortTypeAggregator
	/// to merge different port types together.  However, despite the
	/// simplicity of the code, this is infact the web service that is the
	/// context in the GBG grid system.  Interesting ResourceProperties may
	/// go here in the future such as back links.
	/// </summary>
	[WsdlBaseName("BasicContext",
		 "http://cs.virginia.edu/gbg/BasicContextService")]
	[WebService]
	[WebServiceBinding]
	[WSRFPortType(typeof(ServiceGroupRegistrationPortType))]
	[WSRFPortType(typeof(QueryResourcePropertiesPortType))]
	[WSRFPortType(typeof(GetResourcePropertyPortType))]
	[WSRFPortType(typeof(ImmediateResourceTerminationPortType))]
	[ResourceProperty(GridConstants.LINKS_PROPERTY_NAME, 
		 typeof(LinkData), true, false, "0", "unbounded",
		 Namespace=GridConstants.CONTEXT_NS)]
	public class BasicContextService : ServiceSkeleton
	{
		/// <summary>
		/// Retrieve the factory type for this factory port type.
		/// </summary>
		[ResourceProperty(GridConstants.GRID_FACTORY_TYPE_ELEMENT,
			 typeof(string),
			 false, false, "1", "1",
			 Namespace=GridConstants.GRID_NS)]
		public string FactoryType
		{
			get
			{
				return WellknownEntryTypes.ENTRY_TYPE_CONTEXT.ToString();
			}
		}

		/// <summary>
		/// Construct a new BasicContextService instance.
		/// </summary>
		public BasicContextService()
		{
			InitializeComponent();
		}

		#region Component Designer generated code
		
		//Required by the Web Services Designer 
		private IContainer components = null;
				
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if(disposing && components != null)
			{
				components.Dispose();
			}
			base.Dispose(disposing);		
		}
		
		#endregion

		/// <summary>
		/// This is a factory port type method.  In general, this doesn't
		/// really need to be part of the context class, but for the
		/// initial, default version, it's easy enough to put it here and
		/// works just fine.
		/// </summary>
		/// <param name="creationHints">A parameter which can be used to
		/// give arbitrary "hints" about how the new context should be
		/// created.</param>
		/// <returns>The EPR of the newly created context instance.</returns>
		[WebMethod]
		[SoapDocumentMethodAttribute(
			 GridConstants.FACTORY_CREATE_ACTION,
			 Use=System.Web.Services.Description.SoapBindingUse.Literal,
			 ParameterStyle=SoapParameterStyle.Bare)]
		[return: XmlElement(GridConstants.FACTORY_CREATE_RESULT_ROOT,
					 Namespace=GridConstants.FACTORY_NS)]
		public EndpointReferenceType create(
			[XmlArray(Namespace=GridConstants.FACTORY_NS)]
			[XmlArrayItem(Namespace=GridConstants.FACTORY_NS,
				 IsNullable=false)]
			XmlElement[] creationHints) 
		{
			Hashtable creationParams = new Hashtable();
			creationParams[
				typeof(ServiceGroupPortType).FullName]
				= createInitStructure();
			ServiceBase.Create(null, creationParams);

			return ServiceBase.EPR;
		}

		#region Private Members

		private ServiceGroupPortTypeInit createInitStructure()
		{
			string nspace = GridConstants.GRID_NS;

			ServiceGroupPortTypeInit sgInit =
				new ServiceGroupPortTypeInit();
			MembershipContentRule rule = new MembershipContentRule();
			rule.ContentElements = new XmlQualifiedName[]
				{
					new XmlQualifiedName(GridConstants.ENTRY_NAME_NAME, nspace),
					new XmlQualifiedName(GridConstants.ENTRY_TYPE_NAME, nspace)
				};
			sgInit.Rules.Add(rule);

			return sgInit;
		}

		#endregion
	}
}
