// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Commands;

namespace GridCommand
{
	/// <summary>
	/// This class is a simple "struct" like storage class used merely
	/// as a place holder for data parsed from the command line about the
	/// tool.  It includes the verbosity and debug setting as well as the
	/// name of the requested command and the command's arguments.
	/// </summary>
	public class GridParseData
	{
		// The arguments for the command itself.
		private ICommandLineParser _commandArgs;

		private string _commandName;
		private bool _verbose;
		private bool _debug;

		/// <summary>
		/// Construct a new GridParseData with all of the relevant
		/// information.
		/// </summary>
		/// <param name="args">Any arguments and options to be given
		/// to the command that the invocation requested.</param>
		/// <param name="commandName">The name of the command (such as
		/// "ls", "cd", etc.) to execute.</param>
		/// <param name="verbose">Whether or not verbosity was
		/// requested.</param>
		/// <param name="debug">Whether or not debug statements were
		/// requested.</param>
		public GridParseData(ICommandLineParser args,
			string commandName, bool verbose, bool debug)
		{
			_commandArgs = args;
			_commandName = commandName;
			_verbose = verbose;
			_debug = debug;
		}

		/// <summary>
		/// Retrieve the Command's commandline arguments.
		/// </summary>
		public ICommandLineParser CommandArgs
		{
			get
			{
				return _commandArgs;
			}
		}

		/// <summary>
		/// Retrieve the command name to execute.
		/// </summary>
		public string CommandName
		{
			get
			{
				return _commandName;
			}
		}

		/// <summary>
		/// Retrieve whether or not verbosity was requested.
		/// </summary>
		public bool Verbose
		{
			get
			{
				return _verbose;
			}
		}

		/// <summary>
		/// Retrieve whether or not Debug statements were requested.
		/// </summary>
		public bool Debug
		{
			get
			{
				return _debug;
			}
		}
	}
}