// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid;
using Grid.Commands;

namespace GridCommand
{
	/// <summary>
	/// A simple class for parsing command line data for the Grid program.
	/// This class is NOT responsible for parsing or understanding the
	/// command line options and arguments for the grid command itself, but
	/// only for identifying the command and any options that are relavent
	/// for the grid tool.  Other arguments and options are parsed separately
	/// and handed off to the command instance for use.
	/// </summary>
	public class Parsing
	{
		private const string _GRID_EXECUTABLE_NAME = "grid";
		private const string _DEBUG_OPTION = "--debug";
		private const string _VERBOSE_OPTION = "--verbose";

		private const string USAGE =
			"grid [--verbose] [--debug] <command-name> <command-args>";

		/// <summary>
		/// Given a set of commandline arguments, parse out the relavent
		/// data and return the resultant information.
		/// </summary>
		/// <param name="args">The commandline arguments to parse.</param>
		/// <returns>An instance of the GridParseData class which
		/// contains all of the information relavent to the grid program.
		/// </returns>
		static public GridParseData parse(string []args)
		{
			string commandName = null;
			bool verbose = false;
			bool debug = false;

			int lcv;
			for (lcv = 0; lcv < args.Length; lcv++)
			{
				if (args[lcv].Equals(_DEBUG_OPTION))
					debug = true;
				else if (args[lcv].Equals(_VERBOSE_OPTION))
					verbose = true;
				else
				{
					commandName = args[lcv];
					break;
				}
			}

			if (commandName == null)
				throw new CommandUsageException(_GRID_EXECUTABLE_NAME, USAGE);

			return new GridParseData(
				new DefaultCommandLineParser(args, lcv + 1),
				commandName, verbose, debug);
		}
	}
}