// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

namespace Grid.Commands
{
	/// <summary>
	/// This abstract class is merely a convenience class for command
	/// factories.  The real requirement for a command factory is that it
	/// implement the ICommandFactory interface.  However, since a lot of
	/// the functionallity of an ICommandFactory is to store and give access
	/// to the command name and the usage, we collect that common
	/// functionallity into this abstract class.  Command factories are then
	/// welcome to, if they want, derive off of this class.  If not, they can
	/// implement the required methods and properties in some other way.
	/// </summary>
	public abstract class AbstractCommandFactory : ICommandFactory
	{
		private string _commandName;
		private string _usage;

		/// <summary>
		/// Create a new AbstractCommandFactory by giving it the information
		/// it needs to distributed.
		/// </summary>
		/// <param name="commandName">The name of the command that this
		/// factory is able to instantiate.</param>
		/// <param name="usage">The usage string to print out for this command
		/// if that information is requested.</param>
		protected AbstractCommandFactory(
			string commandName,
			string usage)
		{
			_commandName = commandName;
			_usage = usage;
		}

		#region ICommandFactory Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommandFactory.CommandName"/>
		/// </summary>
		public string CommandName
		{
			get
			{
				return _commandName;
			}
		}

		/// <summary>
		/// <see cref="Grid.Commands.ICommandFactory.Usage"/>
		/// </summary>
		public string Usage
		{
			get
			{
				return _usage;
			}
		}

		/// <summary>
		/// <see cref="Grid.Commands.ICommandFactory.create"/>
		/// </summary>
		/// <param name="commandLine">The command line arguments to create
		/// the new command with.</param>
		/// <returns>An ICommand instance that implements the requested
		/// command type.</returns>
		public abstract ICommand create(ICommandLineParser commandLine);

		#endregion
	}
}
