// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid;

namespace Grid.Commands
{
	/// <summary>
	/// Any exception which a command throws will be derived off of this class.
	/// This isn't to say that all exceptions flying out of a command are 
	/// derived off of this, but if the exception itself is
	/// created by the command, it will be.
	/// </summary>
	public class CommandException : GridException
	{
		/// <summary>
		/// Create a new Command exception with a given message.
		/// </summary>
		/// <param name="msg">The message to create the exception with.</param>
		public CommandException(string msg)
			: base(msg)
		{
		}

		/// <summary>
		/// Create a new exception with a given message, and an exception that
		/// caused this error to occur.
		/// </summary>
		/// <param name="msg">The message to create the exception with.</param>
		/// <param name="innerException">The cause of this exception.</param>
		public CommandException(string msg, Exception innerException)
			: base(msg, innerException)
		{
		}
	}
}
