// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to change his/her current
	/// working directory or context.  Users wishing to do this from code
	/// should use the GridCdOperation rather then the GridCdCommand.
	/// </summary>
	public class GridCdCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "cd";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "cd [<grid-path>]";
			}
		}

		#endregion

		private string _path = null;

		/// <summary>
		/// Create a new GridCdCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridCdCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null && cmdLine.Options.Length > 0)
				throw new CommandUsageException(CommandName, Usage);

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				return;

			if (args.Length > 1)
				throw new CommandUsageException(CommandName, Usage);

			_path = cmdLine.Arguments[0];
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			if (_path == null)
				GridCdOperation.chdir();
			else
				GridCdOperation.chdir(_path);
		}

		#endregion
	}
}