// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.IO;
using System.Xml;
using System.Xml.Serialization;

using Grid.Operations;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to connect to a new
	/// grid.  Users wishing to do this from code should use the 
	/// GridConnectOperation rather then the GridConnectCommand.
	/// </summary>
	public class GridConnectCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "connect";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "connect <grid-file>";
			}
		}

		#endregion

		private string _gridFile = null;

		/// <summary>
		/// Create a new GridConnectCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridConnectCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null && cmdLine.Options.Length > 0)
				throw new CommandUsageException(CommandName, Usage);

			string []args = cmdLine.Arguments;
			if (args == null || args.Length != 1)
				throw new CommandUsageException(CommandName, Usage);

			_gridFile = args[0];
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridConnectOperation.connect(_gridFile);
		}

		#endregion
	}
}