// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to copy files in context
	/// space.  Users wishing to do this from code should use the 
	/// GridCpOperation rather then the GridCpCommand.
	/// </summary>
	public class GridCpCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "cp";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "cp <path1> <path2> [ <path3> ... ]\n"
					+ "\tWHERE\n"
					+ "<path> is [local:]file-path";
			}
		}

		#endregion

		private PathExpressionCollection _paths = null;

		/// <summary>
		/// Create a new GridCpCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridCpCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null && cmdLine.Options.Length > 0)
				throw new CommandUsageException(CommandName, Usage);

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				throw new CommandUsageException(CommandName, Usage);

			_paths = new PathExpressionCollection(
				cmdLine.Arguments);
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridCpOperation.cp(_paths);
		}

		#endregion
	}
}