// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to acquire information about
	/// context space or about entries in context space.  Currently, this
	/// command only supports information about EPRs, but it is intended to grow
	/// over time to accomodate more types of information.  Users wishing to do
	/// this from code should use the GridInfoOperation rather then the
	/// GridInfoCommand.
	/// </summary>
	public class GridInfoCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "info";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "info --epr <grid-path> [ <grid-path> ...]";
			}
		}

		#endregion

		private bool _isEPR = false;
		private PathExpressionCollection _paths = null;

		/// <summary>
		/// Create a new GridInfoCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridInfoCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options == null || !cmdLine.hasOption("epr"))
				throw new CommandUsageException(CommandName, Usage);

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				throw new CommandUsageException(CommandName, Usage);

			_paths = new PathExpressionCollection(
				cmdLine.Arguments);
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridInfoOperation.info(_paths, _isEPR);
		}

		#endregion
	}
}