// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to list the contents of
	/// Context space.  Users wishing to do this from code should use the
	/// GridLsOperation rather then the GridLsCommand.
	/// </summary>
	public class GridLsCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "ls";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "ls [-lad] [path1 ...]";
			}
		}

		#endregion

		private bool _isLong = false;
		private bool _isAll = false;
		private bool _isDir = false;

		private PathExpressionCollection _paths = null;

		/// <summary>
		/// Create a new GridLsCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridLsCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null)
			{
				if (cmdLine.hasOption("l"))
					_isLong = true;
				if (cmdLine.hasOption("a"))
					_isAll = true;
				if (cmdLine.hasOption("d"))
					_isDir = true;
			}

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				return;

			_paths = new PathExpressionCollection(
				cmdLine.Arguments);
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridLsOperation.ls(_paths, _isLong, _isAll, _isDir);
		}

		#endregion
	}
}