// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to create a new directory or
	/// context.  Users wishing to do this from code should use the
	/// GridMkdirOperation rather then the GridMkdirCommand.
	/// </summary>
	public class GridMkdirCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "mkdir";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "mkdir [-p] <path1> [ <path2> ...]";
			}
		}

		#endregion

		private bool _includeParents = false;

		private PathExpressionCollection _paths = null;

		/// <summary>
		/// Create a new GridMkdirCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridMkdirCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null)
			{
				if (cmdLine.hasOption("p"))
					_includeParents = true;
			}

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				throw new CommandUsageException(CommandName, Usage);

			_paths = new PathExpressionCollection(
				cmdLine.Arguments);
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridMkdirOperation.mkdir(_paths, _includeParents);
		}

		#endregion
	}
}