// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to retrieve all of, or part
	/// of the ResourceProperties document for a given context entry.  Users 
	/// wishing to do this from code should use the GridPropertiesOperation 
	/// rather then the GridPropertiesCommand.
	/// </summary>
	public class GridPropertiesCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "properties";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "properties --query <grid-path> [<query>]";
			}
		}

		#endregion

		private bool _isQuery = false;
		private PathExpressionCollection _path = null;
		private string _query = null;

		/// <summary>
		/// Create a new GridPropertiesCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridPropertiesCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options == null || !cmdLine.hasOption("query"))
				throw new CommandUsageException(CommandName, Usage);
			else
				_isQuery = true;

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0 || args.Length > 2)
				throw new CommandUsageException(CommandName, Usage);

			_path = new PathExpressionCollection(args[0]);
			if (args.Length == 2)
				_query = args[1];
			else
				_query = ".";
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			if (_query == null)
				GridPropertiesOperation.properties(_path, _isQuery);
			else
				GridPropertiesOperation.properties(_path, _isQuery, _query);
		}

		#endregion
	}
}