// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;
using Grid.ContextSpace;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to remove entries from
	/// context space and possibly destroy EPRs as well.  Users wishing to do
	/// this from code should use the GridRmOperation rather then the 
	/// GridRmCommand.
	/// </summary>
	public class GridRmCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "rm";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "rm [--no-destroy] <path1> [ <path2> ...]";
			}
		}

		#endregion

		private bool _noDestroy = false;
		private PathExpressionCollection _paths = null;

		/// <summary>
		/// Create a new GridRmCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridRmCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null)
			{
				if (cmdLine.hasOption("no-destroy"))
					_noDestroy = true;
			}

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				throw new CommandUsageException(CommandName, Usage);

			_paths = new PathExpressionCollection(
				cmdLine.Arguments);
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridRmOperation.rm(_paths, _noDestroy);
		}

		#endregion
	}
}