// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Operations;

namespace Grid.Commands
{
	/// <summary>
	/// This command is used when the user wishes to acquire usage information
	/// about the grid command itself, or about a sub command such as ls, or
	/// mkdir.  Users wishing to do this from code should use the 
	/// GridUsageOperation rather then the GridUsageCommand.
	/// </summary>
	public class GridUsageCommand : ICommand
	{
		#region Default Factory Tokens

		/// <summary>
		/// The name of this command.
		/// </summary>
		static public string CommandName
		{
			get
			{
				return "usage";
			}
		}

		/// <summary>
		/// The usage string which describes this command.
		/// </summary>
		static public string Usage
		{
			get
			{
				return "usage [command]";
			}
		}

		#endregion

		private string _command = null;

		/// <summary>
		/// Create a new GridUsageCommand with the given command line.
		/// </summary>
		/// <param name="cmdLine">The CommandLine arguments to create
		/// this command with.</param>
		public GridUsageCommand(ICommandLineParser cmdLine)
		{
			if (cmdLine.Options != null && cmdLine.Options.Length > 0)
				throw new CommandUsageException(CommandName, Usage);

			string []args = cmdLine.Arguments;
			if (args == null || args.Length == 0)
				return;
			if (args.Length > 1)
				throw new CommandUsageException(CommandName, Usage);
			_command = args[0];
		}

		#region ICommand Members

		/// <summary>
		/// <see cref="Grid.Commands.ICommand.run"/>
		/// </summary>
		public void run()
		{
			GridUsageOperation.usage(_command);
		}

		#endregion
	}
}