// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

namespace Grid.Commands
{
	/// <summary>
	/// The common interface which all command factories must implement.
	/// </summary>
	public interface ICommandFactory
	{
		/// <summary>
		/// This is the name of the command that this factory creates.
		/// </summary>
		string CommandName { get; }

		/// <summary>
		/// This is the usage for the command that this factory creates.
		/// </summary>
		string Usage { get; }

		/// <summary>
		/// Create a new command from this factory and initialize it with
		/// the given command line arguments.
		/// </summary>
		/// <param name="commandLine">The commandline arguments that the
		/// new command is to be initialized with.</param>
		/// <returns>The new command that was created by the factory.
		/// </returns>
		ICommand create(ICommandLineParser commandLine);
	}
}
