// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;

using UVa.GCG.WSRF.Common.WS.Addressing;

namespace Grid.ContextSpace
{
	/// <summary>
	/// An abstract base class which implements much of the required
	/// functionallity from the IEntryFactory interface.  This class is
	/// available to users who wish to gain the functionallity provided
	/// and implement the IEntryFactory interface.  However, it's always 
	/// possible for a user to implement this functionallity on their own, 
	/// thereby possibly allowing them to derive off of some other class 
	/// that they feel is appropriate.
	/// </summary>
	public abstract class AbstractEntryFactory : IEntryFactory
	{
		private string _commonName;
		private XmlQualifiedName _entryType;

		/// <summary>
		/// Create a new AbstractEntryFactory.
		/// </summary>
		/// <param name="commonName">The common name that is given to this
		/// factory type.  This common name is used when displaying the
		/// long listing information for a factory.  It gives the "common"
		/// type name for what the factory creates.  We could have chosen to
		/// have given the full QName for the type, but that seemed a little
		/// TOO verbose.</param>
		/// <param name="entryType">The QName of the context space entry type
		/// which this factory creates.</param>
		protected AbstractEntryFactory(
			string commonName,
			XmlQualifiedName entryType)
		{
			_commonName = commonName;
			_entryType = entryType;
		}

		#region IEntryFactory Members

		/// <summary>
		/// <see cref="Grid.ContextSpace.IEntryFactory.CommonName"/>
		/// </summary>
		public string CommonName
		{
			get
			{
				return _commonName;
			}
		}

		/// <summary>
		/// <see cref="Grid.ContextSpace.IEntryFactory.EntryType"/>
		/// </summary>
		public XmlQualifiedName EntryType
		{
			get
			{
				return _entryType;
			}
		}

		/// <summary>
		/// <see cref="Grid.ContextSpace.IEntryFactory.create"/>
		/// </summary>
		public abstract IEntry create(string name,
			EndpointReferenceType epr,
			IEntry parent);

		#endregion
	}
}