// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;

using UVa.GCG.WSRF.Common.WS.Addressing;

namespace Grid.ContextSpace
{
	/// <summary>
	/// An abstract base class for GridEntries.  See IGridEntry for details
	/// on what this interface is for.
	/// </summary>
	public abstract class AbstractGridEntry : AbstractEntry, IGridEntry
	{
		private EndpointReferenceType _epr;

		/// <summary>
		/// Create a new AbstractGridEntry.
		/// </summary>
		/// <param name="epr">The EPR of the service endpoint for which this
		/// entry refers.  This parameter cannot be null or an
		/// ArgumentNullException will be thrown.</param>
		/// <param name="entryName">The name of this entry in context spaec.
		/// </param>
		/// <param name="entryType">The QName of the type for which this
		/// entry is a wrapper.</param>
		/// <param name="parent">The parent, if available, of this entry.
		/// See <see cref="Grid.ContextSpace.IEntry.Parent"/> for details.
		/// </param>
		protected AbstractGridEntry(
			EndpointReferenceType epr,
			string entryName,
			XmlQualifiedName entryType,
			IEntry parent)
			: base(entryName, entryType, parent)
		{
			_epr = epr;
		}

		#region IEntry Members

		/// <summary>
		/// <see cref="Grid.ContextSpace.IEntry.Local"/>
		/// </summary>
		public override bool Local
		{
			get
			{
				return false;
			}
		}

		#endregion

		#region IGridEntry Members

		/// <summary>
		/// <see cref="Grid.ContextSpace.IGridEntry.EPR"/>
		/// </summary>
		public EndpointReferenceType EPR
		{
			get
			{
				return _epr;
			}
		}

		#endregion
	}
}