// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;

using UVa.GCG.WSRF.Common.WS;
using UVa.GCG.WSRF.Common.WS.Addressing;

namespace Grid.ContextSpace
{
	/// <summary>
	/// A common interface that all Entry Factories must implement.
	/// </summary>
	public interface IEntryFactory
	{
		/// <summary>
		/// Retrieve the common name for this factory.  The common name
		/// is the name used in it's listing in ls commands for factories
		/// of this type.
		/// </summary>
		string CommonName { get; }

		/// <summary>
		/// Retrieve the type that this factory creates IEntry instances
		/// of.
		/// </summary>
		XmlQualifiedName EntryType { get; }

		/// <summary>
		/// Create a new IEntry instance from this factory.  NOTE that this
		/// create does NOT create new instances or Endpoints in context
		/// space.  Only new IEntry instances that can be used to describe
		/// the entries.
		/// </summary>
		/// <param name="name">The name that the new IEntry is to have.</param>
		/// <param name="epr">The EPR (if applicable) of the new IEntry.  This
		/// parameter can be null if the EPR is not applicable (such as for
		/// a local file or directory).</param>
		/// <param name="parent">The parent IEntry for this entry.  This parent
		/// is not necessary unless the new Entry type is an INotAvailable
		/// entry.  If not, it can be null.</param>
		/// <returns>The new IEntry instance as created by the factory.
		/// </returns>
		IEntry create(string name,
			EndpointReferenceType epr,
			IEntry parent);
	}
}