// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Collections;
using System.Xml;

namespace Grid.ContextSpace
{
	/// <summary>
	/// A common interface that all entries which don't in fact currently
	/// exist, must implement.  An entry that doesn't exist is one for which
	/// a path was given, but that path didn't resolve to any known existing
	/// endpoint or local file or directory.  It can however later be created.
	/// </summary>
	public interface INotAvailableEntry : IEntry
	{
		/// <summary>
		/// Create this "not available" entry as a new directory.
		/// </summary>
		/// <param name="createParents">Do we allow our parents to be
		/// created if they also don't exist?</param>
		/// <param name="creationHints">Any creation hints which might
		/// be useful when creating this directory.</param>
		/// <returns>The new IEntry that should replace this one.</returns>
		IEntry createDirectory(bool createParents, Hashtable creationHints);

		/// <summary>
		/// Create this "not available" entry as a new file.
		/// </summary>
		/// <param name="createParents">Do we allow our parents to be
		/// created if they also don't exist?</param>
		/// <param name="creationHints">Any creation hints which might
		/// be useful when creating this directory.</param>
		/// <returns>The new IEntry that should replace this one.</returns>
		IEntry createFile(bool createParents, Hashtable creationHints);

		/// <summary>
		/// Create this "not available" entry as a entry of the given type.
		/// </summary>
		/// <param name="createParents">Do we allow our parents to be
		/// created if they also don't exist?</param>
		/// <param name="type">The type to create this new instancce
		/// as.</param>
		/// <param name="creationHints">Any creation hints which might
		/// be useful when creating this directory.</param>
		/// <returns>The new IEntry that should replace this one.</returns>
		IEntry create(bool createParents, XmlQualifiedName type,
			Hashtable creationHints);
	}
}