// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;
using System.Xml.Serialization;

using UVa.GCG.WSRF.Common.WS;
using UVa.GCG.WSRF.Common.WS.Addressing;

using Grid;

namespace Grid.ContextSpace
{
	/// <summary>
	/// An XMLSerializable type that represents link data that can be
	/// stored as a resource property with a context.
	/// </summary>
	[XmlRoot(GridConstants.LINK_DATA_ROOT,
		 Namespace=GridConstants.GRID_NS)]
	public class LinkData
	{
		private EndpointReferenceType _root;
		private EndpointReferenceType _parent;
		private string _name;

		/// <summary>
		/// Construct a new LinkData instance.
		/// </summary>
		/// <param name="name">The name that this context has in the link
		/// that it represents.</param>
		/// <param name="root">The root context EPR for the context space
		/// which this link represents.</param>
		/// <param name="parent">The EPR of the parent context which this
		/// context link is a child of.</param>
		public LinkData(string name,
			EndpointReferenceType root,
			EndpointReferenceType parent)
		{
			_root = root;
			_parent = parent;
			_name = name;
		}

		/// <summary>
		/// Required for XMLSerialization.
		/// </summary>
		public LinkData()
			: this(null, null, null)
		{
		}

		/// <summary>
		/// Get or set the Root EPR for this Link.
		/// </summary>
		public EndpointReferenceType Root
		{
			get
			{
				return _root;
			}

			set
			{
				_root = value;
			}
		}

		/// <summary>
		/// Get or set the Parent EPR for this link.  Essentially, the
		/// back pointer.
		/// </summary>
		public EndpointReferenceType Parent
		{
			get
			{
				return _parent;
			}

			set
			{
				_parent = value;
			}
		}

		/// <summary>
		/// The name of this entity in the link being represented.
		/// </summary>
		public string Name
		{
			get
			{
				return _name;
			}

			set
			{
				_name = value;
			}
		}
	}
}