// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

namespace Grid.ContextSpace
{
	/// <summary>
	/// A simple class to collection information for an LS operation.
	/// </summary>
	public class LsFormat
	{
		private const string _FORMAT_STRING =
			"{0,-32} {1}";

		private string _description = null;
		private string _name = null;

		/// <summary>
		/// Construct a new LsFormat instance.
		/// </summary>
		/// <param name="name">The name of this entry in the context space.
		/// </param>
		/// <param name="description">The long listing format information for
		/// this entry.</param>
		public LsFormat(string name, string description)
		{
			_name = name;
			_description = description;
		}

		/// <summary>
		/// Construct a new LsFormat instance.
		/// </summary>
		/// <param name="name">The name of this entry in the context space.
		/// </param>
		public LsFormat(string name)
		{
			_name = name;
		}

		/// <summary>
		/// Create the string to display for this LsInformation.
		/// </summary>
		/// <param name="isLong">Should detailed information be
		/// given?</param>
		/// <returns>The string that needs to be displayed for
		/// this entry.</returns>
		public string ToString(bool isLong)
		{
			if (isLong)
				return string.Format(_FORMAT_STRING,
					_description, _name);
			else
				return _name;
		}
	}
}