// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;

using Grid;

namespace Grid.ContextSpace
{
	/// <summary>
	/// An exception type which indicates that no factory could be found to
	/// satisfy a given type.  This exception can be used for both
	/// IEntryFactory as well as grid factories.
	/// </summary>
	public class NoSuitableFactoryException : GridException
	{
		private const string _FORMAT = 
			"No suitable factory could be found to create a new \"{0}\".";

		/// <summary>
		/// Construct a new NoSuitableFactoryException
		/// </summary>
		/// <param name="type">The type for which a factory could not
		/// be found.</param>
		public NoSuitableFactoryException(XmlQualifiedName type)
			: base(string.Format(_FORMAT, type))
		{
		}
	}
}