// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;
using System.Xml.Serialization;

using UVa.GCG.WSRF.Common.WS;

namespace Grid.ContextSpace
{
	/// <summary>
	/// All service group entries contain content elements.  When we look
	/// up the elements, we get back an XML Document which is the serialization
	/// of those elements.  This type matches that document and can be acquired
	/// through deserialization of it.
	/// </summary>
	[XmlRoot("Content",
		 Namespace=WSConstants.WS_SERVICE_GROUPS_XSD_NS)]
	public class ServiceGroupContentType
	{
		private string _entryName;
		private XmlElement _entryType;

		/// <summary>
		/// Required for XML Serializability.
		/// </summary>
		public ServiceGroupContentType()
		{
		}

		/// <summary>
		/// Get or set the entry name of this context element.
		/// </summary>
		[XmlElement(GridConstants.ENTRY_NAME_NAME,
			 Namespace=GridConstants.GRID_NS)]
		public string EntryName
		{
			get
			{
				return _entryName;
			}

			set
			{
				_entryName = value;
			}
		}

		/// <summary>
		/// Get or set the type of entry for this element.
		/// </summary>
		[XmlElement(GridConstants.ENTRY_TYPE_NAME,
			 Namespace=GridConstants.GRID_NS)]
		public XmlElement EntryType
		{
			get
			{
				return _entryType;
			}

			set
			{
				_entryType = value;
			}
		}
	}
}