// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Xml;

using UVa.GCG.WSRF.Common.WS.Addressing;

namespace Grid.ContextSpace
{
	/// <summary>
	/// An IEntry type which represents that fact that the entry
	/// exists, but is not one of a type recognized by the system.
	/// This is perfectly valid, but no further information can be
	/// gleaned from it other then the basic info such as EPR and
	/// name.
	/// </summary>
	public class UnknownEntry : AbstractGridEntry
	{
		/// <summary>
		/// Construct a new UnknownEntry type.
		/// </summary>
		/// <param name="epr">The EPR of the entry.  This parameter is
		/// required to be non-null.</param>
		/// <param name="entryName">The entry name for this entry.</param>
		/// <param name="parent">The parent (if available) for this
		/// entry.</param>
		public UnknownEntry(EndpointReferenceType epr,
			string entryName,
			IEntry parent)
			: base(epr, entryName, WellknownEntryTypes.ENTRY_TYPE_UNKNOWN,
				parent)
		{
		}

		#region IEntry Members

		/// <remarks><see cref="IEntry.format"/></remarks>
		public override LsFormat format(bool isLong)
		{
			return new LsFormat(EntryName, "");
		}

		#endregion
	}
}