// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.IO;
using System.Xml;

namespace Grid
{
	/// <summary>
	/// A collection of useful and often used constants for GridLib.
	/// </summary>
	public class GridConstants
	{
		#region Namespaces

		/// <remarks/>
		public const string GRID_NS = "http://cs.virginia.edu/gbg";
		/// <remarks/>
		public const string FILE_NS = GRID_NS + "/files";
		/// <remarks/>
		public const string CONTEXT_NS = GRID_NS + "/contexts";
		/// <remarks/>
		public const string FACTORY_NS = GRID_NS + "/factories";

		#endregion

		#region XML Serialization

		// Contexts
		/// <remarks/>
		public const string LINK_DATA_ROOT = "LinkData";
		/// <remarks/>
		public const string CONTEXT_ENVIRONMENT_ROOT = "CommandEnvironment";

		// Grid Init Tool
		/// <remarks/>
		public const string GRID_INIT_FACTORY_ROOT = "factory";
		/// <remarks/>
		public const string GRID_INIT_CONFIG_ROOT = "grid-config";
		/// <remarks/>
		public const string GRID_FACTORIES_ARRAY_ELEMENT = "factories";
		/// <remarks/>
		public const string GRID_FACTORY_ARRAY_ITEM_ELEMENT = "grid-factory";
		/// <remarks/>
		public const string GRID_FACTORY_TYPE_ELEMENT = "type";
		/// <remarks/>
		public const string GRID_FACTORY_NAME_ATTR = "name";

		// Extension Library
		/// <remarks/>
		public const string GRID_LIB_CONF_EXT_LIB_ROOT =
			"extension-libraries";
		/// <remarks/>
		public const string GRID_LIB_CONF_EXT_LIB_DESC_ROOT = 
			"extension-library-description";
		/// <remarks/>
		public const string GRID_LIB_CONF_EXT_LIB_DESC_NAME =
			"name";
		/// <remarks/>
		public const string GRID_LIB_CONF_EXT_LIB_DESC_FILE =
			"file-name";

		// EPR Importation
		/// <remarks/>
		public const string EPR_INFO_ROOT = "endpoint";

		// Factory Type
		/// <remarks/>
		public const string FACTORY_CREATE_RESULT_ROOT = "endpoint";
		/// <remarks/>
		public const string GRID_FACTORY_ENDPOINT_ELEMENT = "factory-endpoint";

		// Files
		/// <remarks/>
		public const string FILE_READ_RESULT_ROOT = "file-data";
		/// <remarks/>
		public const string FILE_READ_OFFSET_ROOT = "offset";
		/// <remarks/>
		public const string FILE_READ_SIZE_ROOT = "size";

		/// <remarks/>
		public const string FILE_WRITE_RESULT_ROOT = "bytes-written";
		/// <remarks/>
		public const string FILE_WRITE_OFFSET_ROOT = "offset";
		/// <remarks/>
		public const string FILE_WRITE_DATA_ROOT = "file-data";

		/// <remarks/>
		public const string FILE_TRUNCAPPEND_RESULT_ROOT = "bytes-written";
		/// <remarks/>
		public const string FILE_TRUNCAPPEND_DATA_ROOT = "file-data";

		/// <remarks/>
		public const string FILE_APPEND_RESULT_ROOT = "bytes-written";
		/// <remarks/>
		public const string FILE_APPEND_DATA_ROOT = "file-data";

		#endregion

		#region Content Rules

		/// <remarks/>
		public const string ENTRY_TYPE_NAME = "entry-type";
		/// <remarks/>
		public const string ENTRY_NAME_NAME = "entry-name";

		/// <remarks/>
		static public readonly XmlQualifiedName ENTRY_TYPE_QNAME =
			new XmlQualifiedName(ENTRY_TYPE_NAME, GRID_NS);
		/// <remarks/>
		static public readonly XmlQualifiedName ENTRY_NAME_QNAME =
			new XmlQualifiedName(ENTRY_NAME_NAME, GRID_NS);

		#endregion

		#region Resource Properties

		/// <remarks/>
		public const string FILE_SIZE_PROPERTY_NAME = "file-size";
		/// <remarks/>
		static public readonly XmlQualifiedName FILE_SIZE_PROPERTY
			= new XmlQualifiedName(FILE_SIZE_PROPERTY_NAME, 
				FILE_NS);

		/// <remarks/>
		public const string LINKS_PROPERTY_NAME = "links";
		/// <remarks/>
		static public readonly XmlQualifiedName LINKS_PROPERTY =
			new XmlQualifiedName(LINKS_PROPERTY_NAME, CONTEXT_NS);

		#endregion

		#region SOAP Actions

		/// <remarks/>
		public const string FACTORY_CREATE_ACTION =
			FACTORY_NS + "/create";

		/// <remarks/>
		public const string FILE_READ_ACTION =
			FILE_NS + "/read";
		/// <remarks/>
		public const string FILE_WRITE_ACTION =
			FILE_NS + "/write";
		/// <remarks/>
		public const string FILE_TRUNCAPPEND_ACTION =
			FILE_NS + "/truncAppend";
		/// <remarks/>
		public const string FILE_APPEND_ACTION =
			FILE_NS + "/append";

		#endregion

		#region Miscellaneous

		/// <remarks/>
		public const string XPATH_DIALECT
			= "http://www.w3.org/TR/1999/REC-xpath-19991116";

		#endregion

		#region Environment

		static private DirectoryInfo _gridDirectory = null;
		
		/// <summary>
		/// Retrieve the directory where all grid
		/// </summary>
		static public DirectoryInfo GridLibDirectory
		{
			get
			{
				lock (typeof(GridConstants))
				{
					if (_gridDirectory == null)
					{
						string path = string.Format("{0}\\.grid-lib",
							Environment.GetFolderPath(
							Environment.SpecialFolder.ApplicationData));
						_gridDirectory = new DirectoryInfo(path);

						_gridDirectory =
							GuaranteedDirectory.GetDirectory(_gridDirectory);
					}
				}

				return _gridDirectory;
			}
		}

		#endregion
	}
}