using System;
using System.IO;

namespace Grid
{
	/// <summary>
	/// This class is a type of DirectoryInfo where the directory 
	/// is guaranteed to exist.
	/// </summary>
	public class GuaranteedDirectory
	{
		/// <summary>
		/// Retrieve a directory info for a directory that is guaranteed to
		/// exist.
		/// </summary>
		/// <param name="info">The directory info to guarantee</param>
		/// <returns>The directory info for the guaranteed directory.</returns>
		static public DirectoryInfo GetDirectory(
			DirectoryInfo info)
		{
			if (info.Exists)
				return info;
			info.Create();
			info = new DirectoryInfo(info.FullName);
			if (!info.Exists)
				throw new GridLibException(
					string.Format("Directory \"{0}\" cannot be created.",
						info.FullName));

			return info;
		}
	}
}
