// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Commands;
using Grid.ContextSpace;
using Grid.Env;

namespace Grid.Operations
{
	/// <summary>
	/// A class which collects together all types of Cd operation that
	/// are available programatically.
	/// </summary>
	public class GridCdOperation : IOperation
	{
		/// <summary>
		/// Change directory to a given path.
		/// </summary>
		/// <param name="path">The grid-path expression to change directory
		/// to.</param>
		static public void chdir(string path)
		{
			if (path == null)
				throw new ArgumentNullException("path",
					"Cannot chdir to a null path.");

			IEntry entry = ContextUtilities.PathLookup(path,
				PathLookupFlags.Grid |
				PathLookupFlags.MustExist);

			if (!entry.EntryType.Equals(WellknownEntryTypes.ENTRY_TYPE_CONTEXT))
				throw new CommandException(
					string.Format("Target path \"{0}\" is not a context.", entry.Path));

			chdir((GridContext)entry);
		}

		/// <summary>
		/// Change directory to the root context.
		/// </summary>
		static public void chdir()
		{
			chdir(new GridContext(
                GridLibEnvironment.Instance.ContextEnvironment.RootContext,
					"/", null));
		}

		/// <summary>
		/// Change directory to the GridContext indicated.
		/// </summary>
		/// <param name="context">The GridContext to change directories
		/// to.</param>
		static public void chdir(GridContext context)
		{
			if (context == null)
				throw new ArgumentNullException("context",
					"Cannot chdir to a null context.");

			GridLibEnvironment.Instance.ContextEnvironment.CurrentContext
				= context.EPR;
			GridLibEnvironment.Instance.Modified = true;
		}
	}
}