// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Collections;
using System.Xml;
using System.Xml.Serialization;

using Grid.Commands;
using Grid.ContextSpace;
using Grid.Env;
using Grid.Proxies;

using UVa.GCG.WSRF.Common.WS.Addressing;

namespace Grid.Operations
{
	/// <summary>
	/// Collects together all valid grid connection operations.
	/// </summary>
	public class GridConnectOperation
		: IOperation
	{
		/// <summary>
		/// Connect to a new grid given the context environment for it.
		/// </summary>
		/// <param name="gridInfo">The context environment of the new
		/// grid to connect to.</param>
		static public void connect(CurrentContextEnvironment gridInfo)
		{
			GridLibEnvironment.Instance.ContextEnvironment = gridInfo;
			GridLibEnvironment.Instance.Modified = true;
		}

		/// <summary>
		/// Connect to a new grid given the context environment store
		/// in a file somewhere.
		/// </summary>
		/// <param name="localFile">The name of a file in the local
		/// file system which contains the serialized form of a 
		/// context environment (CurrentContextEnvironment) that we
		/// wish to connect to.</param>
		static public void connect(string localFile)
		{
			connect(CurrentContextEnvironment.load(localFile));
		}
	}
}