// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.IO;
using System.Reflection;

using Grid.Commands;
using Grid.ContextSpace;
using Grid.Env;
using Grid.Extensions;

namespace Grid.Operations
{
	/// <summary>
	/// Collects together the operations which manage the configuration of the grid lib conf
	/// </summary>
	public class GridLibConfOperation : IOperation
	{
		#region Constants

		private const int _BUFFER_SIZE = 1024;

		#endregion

		/// <summary>
		/// Add a new extension library to the current configuration.
		/// </summary>
		/// <param name="assemblyFile">The path to the file that contains the 
		/// assembly.</param>
		/// <param name="libraryName">The common name of the extension.</param>
		/// <param name="libraryDescription">The description for the extension.
		/// </param>
		static public void addExtensionLibrary(
			string assemblyFile, string libraryName, string libraryDescription)
		{
			ExtensionCollection.Instance.addExtensionLibrary(assemblyFile,
				libraryName, libraryDescription);
		}

		/// <summary>
		/// Add a new extension library to the current configuration.
		/// </summary>
		/// <param name="assemblyFile">The path to the file that contains the 
		/// assembly.</param>
		/// <param name="libraryName">The common name of the extension.</param>
		static public void addExtensionLibrary(
			string assemblyFile, string libraryName)
		{
			ExtensionCollection.Instance.addExtensionLibrary(assemblyFile, libraryName);
		}

		/// <summary>
		/// Add a new extension library to the current configuration.
		/// </summary>
		/// <param name="assemblyFile">The path to the file that contains the 
		/// assembly.</param>
		static public void addExtensionLibrary(
			string assemblyFile)
		{
			ExtensionCollection.Instance.addExtensionLibrary(assemblyFile);
		}

		/// <summary>
		/// Remove the named extension library.  Note that this won't have any
		/// effects until the environment is unloaded.
		/// </summary>
		/// <param name="extensionLibraryName">The name of the extension to
		/// remove.</param>
		static public void removeExtensionLibrary(string extensionLibraryName)
		{
			ExtensionCollection.Instance.removeExtensionLibrary(extensionLibraryName);
		}

		/// <summary>
		/// Retrieve a list of all installed extension libraries.
		/// </summary>
		static public ExtensionLibraryDescription[] InstalledExtensionLibraries
		{
			get
			{
				return ExtensionCollection.Instance.InstalledExtensionLibraries;
			}
		}
	}
}