// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Commands;
using Grid.ContextSpace;
using Grid.Env;

namespace Grid.Operations
{
	/// <summary>
	/// Collects together all of the operations that implement the mkdir
	/// functionallity.
	/// </summary>
	public class GridMkdirOperation : IOperation
	{
		/// <summary>
		/// Perform a mkdir operation on a given set of paths.
		/// </summary>
		/// <param name="paths">The collection of paths to mkdir on.</param>
		/// <param name="includeParents">Whether or not parent directories
		/// can be created in order to satisfy path creation.</param>
		static public void mkdir(PathExpressionCollection paths, bool includeParents)
		{
			IEntry[] entries = paths.resolveAll();
			foreach (IEntry entry in entries)
			{
				if (entry.Exists && !includeParents)
					throw new PathAlreadyExistsException(entry.Path);
				if (!entry.Exists)
				{
					INotAvailableEntry g = (INotAvailableEntry)entry;
					g.createDirectory(includeParents, null);
				}
			}
		}
	}
}