// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;

using Grid.Commands;
using Grid.Env;

namespace Grid.Operations
{
	/// <summary>
	/// Collects together the operations which display usage information.
	/// </summary>
	public class GridUsageOperation : IOperation
	{
		/// <summary>
		/// Display usage information about the grid lib executable.
		/// </summary>
		static public void usage()
		{
			usage(null);
		}
		
		/// <summary>
		/// Display usage information about a given gridlib command.
		/// </summary>
		/// <param name="command">The command to display information 
		/// about.</param>
		static public void usage(string command)
		{
			if (command != null)
			{
				ICommandFactory factory = 
					CommandCollection.Instance[command];
				GridLibEnvironment.Instance.Console.Output.WriteLine(
					factory.Usage);
			} 
			else
			{
				GridLibEnvironment.Instance.Console.Output.WriteLine(
					"Commands:");
				foreach (ICommandFactory factory in 
					CommandCollection.Instance.Commands)
				{
					GridLibEnvironment.Instance.Console.Output.WriteLine(
						"\t{0}", factory.CommandName);
				}
			}
		}
	}
}