// Copyright (c) 2004, GBG, University of Virginia, All Rights Reserved
// Author: Mark Morgan, mmm2a@cs.virginia.edu

using System;
using System.Reflection;

namespace Grid
{
	/// <summary>
	/// An exception type that represents the fact that something that hasn't
	/// yet been implemented was invoked.
	/// </summary>
	public class UnimplementedException : GridException
	{
		private const string _FORMAT =
			"{0} in class {1} is unimplemented currently.";

		private Type _sourceType;
		private MemberInfo _sourceMember;

		/// <summary>
		/// Construct a new UnimplementedException.  This construct assumes
		/// that it is the entire class method or property that is 
		/// unimplemented.
		/// </summary>
		/// <param name="sourceType">The class that threw this
		/// exception.</param>
		/// <param name="sourceMember">The method, property, or other
		/// that threw this exception.</param>
		public UnimplementedException(
			Type sourceType, MemberInfo sourceMember)
			: this(sourceType, sourceMember, 
				string.Format(_FORMAT, sourceMember.Name, 
					sourceType.FullName))
		{
			_sourceType = sourceType;
			_sourceMember = sourceMember;
		}

		/// <summary>
		/// Construct a new UnimplementedException.
		/// </summary>
		/// <param name="sourceType">The class that threw this
		/// exception.</param>
		/// <param name="sourceMember">The method, property, or other
		/// that threw this exception.</param>
		/// <param name="msg">The message to display with this exception.
		/// </param>
		public UnimplementedException(
			Type sourceType, MemberInfo sourceMember, string msg)
			: base(msg)
		{
			_sourceType = sourceType;
			_sourceMember = sourceMember;
		}
	}
}