using System;
using System.Collections;

namespace Grid.Utilities
{
	/// <summary>
	/// When a the cache has a lookup that misses for whatever
	/// reason, this is the delegate that gets called to resolve
	/// that miss.
	/// </summary>
	public delegate object CacheEntryResolver(object key);

	/// <summary>
	/// A Least-Recently-Used cache with the optional ability to
	/// time out data that may be stale.
	/// </summary>
	public class LRUCache
	{
		private class DataPackage
		{
			public object Data;
			public DateTime LastUpdated;
			public object Key;

			public DataPackage Previous = null;
			public DataPackage Next = null;

			public DataPackage(object key,
				object data, DateTime lastUpdated)
			{
				Key = key;
				Data = data;
				LastUpdated = lastUpdated;
			}
		}

		private CacheEntryResolver _resolver;
		private TimeSpan _timeToLive;
		private DataPackage _head = null;
		private DataPackage _tail = null;
		private Hashtable _table = null;
		private int _cacheSize;

		/// <summary>
		/// Construct a new LRUCache.
		/// </summary>
		/// <param name="resolver">The resolver to handle cache misses</param>
		/// <param name="cacheSize">The maximum number of elements that can
		/// go into the cache.</param>
		/// <param name="timeToLive">An option parameter that specifies how
		/// long an entry can remain in the cache before it is considered
		/// stale.</param>
		public LRUCache(CacheEntryResolver resolver,
			int cacheSize, TimeSpan timeToLive)
		{
			_resolver = resolver;
			_timeToLive = timeToLive;
			_table = new Hashtable((int)(cacheSize / 0.66));
			_cacheSize = cacheSize;
		}

		/// <summary>
		/// Construct a new LRUCache.
		/// </summary>
		/// <param name="resolver">The resolver to handle cache misses</param>
		/// <param name="cacheSize">The maximum number of elements that can
		/// go into the cache.</param>
		public LRUCache(CacheEntryResolver resolver, int cacheSize)
			: this(resolver, cacheSize, TimeSpan.MaxValue)
		{
		}

		/// <summary>
		/// Retrieve the data item that matches a key.  If the item is not
		/// there, or is stale, the resolver will be used to fill the data
		/// in.
		/// </summary>
		public object this[object key]
		{
			get
			{
				DataPackage pkg = (DataPackage)_table[key];
				if (pkg != null)
				{
				}

				throw new UnimplementedException(
					this.GetType(), this.GetType().GetProperty("this[]"));
			}
		}

		/// <summary>
		/// Eject an item from the cache.
		/// </summary>
		/// <param name="key">The key of the item to eject from the
		/// cache.</param>
		public void eject(object key)
		{
		}
	}
}